@@ -1,6 +1,6 @@
 
-from FormsValidators.rules import Validators
-from FormsValidators.rules import FormValidation
+from FormsValidators import Validators
+from FormsValidators import FormValidation
 
 
 import json
@@ -20,6 +20,12 @@ class jsontools:
 			print(err)
 			return False
 		return True
+
+	def convertJsonToList(data):
+		try:
+			return json.loads(data)
+		except:
+			return False
 	
 	def convertToJson(data):
 
